/***********************************************************************/
/*                                                                     */
/*         USE THE CROSS-SECTIONAL FILE FOR THE 1996 HEALTH COMPONENT  */
/*         (DUMYH35.TXT)                                               */
/*         TO CALCULATE THE NUMBER OF DIABETIC PERSONS                 */
/*         FOR THE AGE GROUPS 12-17, 18-24, 25-44, AND 45 AND OVER     */
/*         AND FOR MALES, FEMALES, AND BOTH,                           */
/*         BY PROVINCE                                                 */
/*                                                                     */
/***********************************************************************/

libname in1 'c:\data';

proc datasets kill;
run;

proc format;
  value fsex    1='males  '
                2='females';

  value fage    1='12-17'
                2='18-24'
                3='25-44'
                4='45+';

  value fdiab   1='Yes'
                0='No ';
run;

data in1.cross;
%let datafid='c:\data\dumyh35.txt';
%include 'c:\data\h35_in.sas';
keep region diab total dhc6_sex males females
     agegrp age1217 age1824 age2544 age45 magegrp fagegrp
     mage1217 mage1824 mage2544 mage45 fage1217 fage1824 fage2544 fage45
     mdiab fdiab diab1217 diab1824 diab2544 diab45
     mdia1217 mdia1824 mdia2544 mdia45 fdia1217 fdia1824 fdia2544 fdia45
     wt56 dhc6_sex total realukey personid;

region=prc6_cur;

if ccc6_1j=1 then diab=1;
else if ccc6_1j=2 then diab=0;
else diab=.;

if diab=. then delete;

/**********************************************/
/* define domains of interest with 0/1 values */
/**********************************************/

total=1;

 /* sex */

if dhc6_sex=1 then males=1;
else males=0;

if dhc6_sex=2 then females=1;
else females=0;


 /* age group */

if dhc6_age < 18 then agegrp=1;
else if dhc6_age < 25 then agegrp=2;
else if dhc6_age < 45 then agegrp=3;
else agegrp=4;

if agegrp=1 then age1217=1; else age1217=0;
if agegrp=2 then age1824=1; else age1824=0;
if agegrp=3 then age2544=1; else age2544=0;
if agegrp=4 then age45=1; else age45=0;


 /* age group and sex */

if agegrp=1 then do;
  if dhc6_sex=1 then magegrp=1;
  else if dhc6_sex=2 then fagegrp=1;
end;
else if agegrp=2 then do;
  if dhc6_sex=1 then magegrp=2;
  else if dhc6_sex=2 then fagegrp=2;
end;
else if agegrp=3 then do;
  if dhc6_sex=1 then magegrp=3;
  else if dhc6_sex=2 then fagegrp=3;
end;
else if agegrp=4 then do;
  if dhc6_sex=1 then magegrp=4;
  else if dhc6_sex=2 then fagegrp=4;
end;

if magegrp=1 then mage1217=1; else mage1217=0;
if magegrp=2 then mage1824=1; else mage1824=0;
if magegrp=3 then mage2544=1; else mage2544=0;
if magegrp=4 then mage45=1; else mage45=0;

if fagegrp=1 then fage1217=1; else fage1217=0;
if fagegrp=2 then fage1824=1; else fage1824=0;
if fagegrp=3 then fage2544=1; else fage2544=0;
if fagegrp=4 then fage45=1; else fage45=0;


 /* diabetes*sex */

if diab=1 then do;
  if dhc6_sex=1 then mdiab=1; else mdiab=0;   /* diabetic males   */
  if dhc6_sex=2 then fdiab=1; else fdiab=0;   /* diabetic females */
end;
else if diab=2 then do;
  mdiab=0;
  fdiab=0;
end;


 /* diabetes*age group */

if diab=1 then do;
  if age1217=1 then diab1217=1; else diab1217=0;
  if age1824=1 then diab1824=1; else diab1824=0;
  if age2544=1 then diab2544=1; else diab2544=0;
  if age45=1   then diab45=1; else diab45=0;
end;
else do;
  diab1217=0;
  diab1824=0;
  diab2544=0;
  diab45=0;
end;


 /* diabetes*sex*age group */

if mdiab=1 then do;
  if age1217=1 then mdia1217=1; else mdia1217=0;
  if age1824=1 then mdia1824=1; else mdia1824=0;
  if age2544=1 then mdia2544=1; else mdia2544=0;
  if age45=1   then mdia45=1; else mdia45=0;
end;
else do;
  mdia1217=0;
  mdia1824=0;
  mdia2544=0;
  mdia45=0;
end;

if fdiab=1 then do;
  if age1217=1 then fdia1217=1; else fdia1217=0;
  if age1824=1 then fdia1824=1; else fdia1824=0;
  if age2544=1 then fdia2544=1; else fdia2544=0;
  if age45=1   then fdia45=1; else fdia45=0;
end;
else do;
  fdia1217=0;
  fdia1824=0;
  fdia2544=0;
  fdia45=0;
end;

proc freq data=in1.cross;
format agegrp fage. magegrp fage. fagegrp fage. diab fdiab.;
table region*(diab diab2544 mdia45 fdia45)
      region*diab*total region*mdia45*mage45 region*diab45*age45 ;
weight wt56;
title 'Number of diabetic by age group and region';
run;
