/***********************************************************************/
/*                                                                     */
/*         USE THE CROSS-SECTIONAL FILE FOR THE 1996 HEALTH COMPONENT  */
/*         (DUMY356.TXT)                                               */
/*         TO STUDY THE RELATION BETWEEN CHRONIC CONDITION REPORTING   */
/*         AND THE TYPE OF INTERVIEW (PROXY VS NON-PROXY)              */
/*                                                                     */
/***********************************************************************/

libname in1 'c:\data';

data in1.dumyh356;
  %let datafid="c:\data\dumyh356.txt";
  %include "c:\data\h356_in.sas";
  keep realukey personid dhc6_age dhc6_sex am56_pxy ccc6dany
  age1217 age1820 age2124 age2534 age3544 age4554 age5564
  age6574 age7584 age85 female nonproxy wt66;
  if dhc6_age >= 12;

/* Dummy variables for the age group */

  age1217=0;
  age1820=0;
  age2124=0;
  age2534=0;
  age3544=0;
  age4554=0;
  age5564=0;
  age6574=0;
  age7584=0;
  age85=0;

  if 12 <= dhc6_age <=17 then age1217=1;
  if 18 <= dhc6_age <=20 then age1820=1;
  if 21 <= dhc6_age <=24 then age2124=1;
  if 25 <= dhc6_age <=34 then age2534=1;
  if 35 <= dhc6_age <=44 then age3544=1;
  if 45 <= dhc6_age <=54 then age4554=1;
  if 55 <= dhc6_age <=64 then age5564=1;
  if 65 <= dhc6_age <=74 then age6574=1;
  if 75 <= dhc6_age <=84 then age7584=1;
  if dhc6_age>=85 then age85=1;

  female=0;
  if dhc6_sex=2 then female=1;

/* Missing values */

  if ccc6dany>2 then ccc6dany=.;
  if ccc6dany=2 then ccc6dany=0;

  nonproxy=0;
  if am56_pxy>2 then nonproxy=.;
  if am56_pxy=2 then nonproxy=1;
run;

proc logistic data=in1.dumyh356 descending;
     model ccc6dany = nonproxy age1820 age2124 age2534 age3544
       age4554 age5564 age6574 age7584 age85 female;
     weight wt66;
title 'Chronic conditions';
run;
